==> mastapy-14.0.0b2.tar.gz: mastapy-14.0.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1688.py <==
"""FlowRate"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.utility.units_and_measurements import _1652
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_FLOW_RATE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "FlowRate"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="FlowRate")
    CastSelf = TypeVar("CastSelf", bound="FlowRate._Cast_FlowRate")


__docformat__ = "restructuredtext en"
__all__ = ("FlowRate",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FlowRate:
    """Special nested class for casting FlowRate to subclasses."""

    __parent__: "FlowRate"

    @property
    def measurement_base(self: "CastSelf") -> "_1652.MeasurementBase":
        return self.__parent__._cast(_1652.MeasurementBase)

    @property
    def flow_rate(self: "CastSelf") -> "FlowRate":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class FlowRate(_1652.MeasurementBase):
    """FlowRate

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FLOW_RATE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_FlowRate":
        """Cast to another type.

        Returns:
            _Cast_FlowRate
        """
        return _Cast_FlowRate(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1688.py <==
"""Cycles"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_CYCLES = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Cycles"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Cycles")
    CastSelf = TypeVar("CastSelf", bound="Cycles._Cast_Cycles")


__docformat__ = "restructuredtext en"
__all__ = ("Cycles",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Cycles:
    """Special nested class for casting Cycles to subclasses."""

    __parent__: "Cycles"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def cycles(self: "CastSelf") -> "Cycles":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Cycles(_1666.MeasurementBase):
    """Cycles

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYCLES

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Cycles":
        """Cast to another type.

        Returns:
            _Cast_Cycles
        """
        return _Cast_Cycles(self)
